# Study validators

Deterministic grading rules are defined by `scoring.yaml` and implemented by `abi-study grade`. Hidden task gold is generated under `fixtures/gold/` and must not be mounted into an Agent trial.
